<?php

namespace AdministracionBundle\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\HttpFoundation\Request;
use Doctrine\ORM\Tools\Pagination\Paginator;
use IncidenciaBundle\Form\incidenciaType;
use Symfony\Component\HttpFoundation\Response;

class IncidenciaController extends Controller
{
    public function indexAction(Request $request, $page)
    {
        if($this->get('security.authorization_checker')->isGranted('ROLE_SUPER_ADMIN') === true){
            if ($page == NULL){
                $page = 1;
            }
            $text = $request->query->get("text");
            $idbusiness = intval($request->query->get("idbusiness"));
            $resuelta = intval($request->query->get("resuelta"));
            $tipo = intval($request->query->get("tipo"));
            
            $em = $this->getDoctrine()->getManager();
            $usuarioQuery = $em->getRepository('IncidenciaBundle:incidencia')
                    ->findIncidenciasQuery($idbusiness, $text, $resuelta, $tipo);
            $pageSize = 20;
            $incidencias = $this->getPaginate($pageSize, $page, $usuarioQuery);
            $totalItems = count($incidencias);
            $pagescount = ceil($totalItems / $pageSize);
            
            $abusiness = $em->getRepository('PagoBundle:business')->findBusiness();
            
            return $this->render('AdministracionBundle:Incidencia:incidenciaslist.html.twig' ,
                                array(  
                                    "incidencias" => $incidencias,
                                    "totalItems" => $totalItems,
                                    "pagesCount" => $pagescount,
                                    "currentpage" => $page,
                                    "text" => $text,
                                    "idbusiness" => $idbusiness,
                                    "abusiness" => $abusiness,
                                    "resuelta" => $resuelta,
                                    "tipo" => $tipo
                                    )
                                );
        }
        return $this->redirectToRoute('login');
    }
    
    public function getPaginate($pageSize, $currentPage, $queryBuilder){
        if ($currentPage > 0){
            $queryBuilder->setFirstResult($pageSize * ($currentPage - 1))->setMaxResults($pageSize);
        }
        $paginator = new Paginator($queryBuilder, $fetchJoinCollection = true);
        return $paginator;
    }
    
    public function editAction(Request $request, $id)
    {
        if(($this->get('security.authorization_checker')->isGranted('ROLE_SUPER_ADMIN') === true)){
            $em = $this->getDoctrine()->getManager();
            if($id == NULL){
               $id = -1;
            }
            $incidencia = $em->getRepository('IncidenciaBundle:incidencia')->find($id);
            if ($incidencia != NULL){
                $form = $this->createForm(incidenciaType::class, $incidencia, 
                            array("attr" => array("disabled" => FALSE)));
                
                if($request->getMethod() == 'POST'){
                     $form->handleRequest($request);
                        if ($form->isSubmitted() && $form->isValid()) {
                            $em->persist($incidencia);
                            $em->flush();
                            
                            if ($incidencia->getResuelta()){
                                if ($incidencia->getFecharesuelta() != NULL){
                                    $incidencia->setFecharesuelta(new \DateTime());
                                }
                            }else{
                                $incidencia->setFecharesuelta(NULL);
                            }
                            $em->persist($incidencia);
                            $em->flush();
                            
                            return $this->redirectToRoute('incidencias_index');
                        }
                }
                return $this->render('AdministracionBundle:Incidencia:incidenciaedit.html.twig',
                        array('form'=>$form->createView(),
                                'incidencia'=>$incidencia));
            }
        }
        return $this->redirectToRoute('incidencias_index');
    }
    
    public function deleteAction($id){
        if(($this->get('security.authorization_checker')->isGranted('ROLE_SUPER_ADMIN') === true)){
            $em = $this->getDoctrine()->getManager();
             $incidencia = $em->getRepository("IncidenciaBundle:incidencia")
                        ->find($id);
            if($incidencia){
                $incidencia->setEliminada(1);
                $em->persist($incidencia);
                $em->flush();
            }
        }
        return $this->redirectToRoute('incidencias_index');
    }
    
    public function imagenAction($id){
        $em = $this->getDoctrine()->getManager();
        if($this->get('security.authorization_checker')->isGranted('ROLE_SUPER_ADMIN') === true){
            $incidencia = $em->getRepository("IncidenciaBundle:incidencia")
                        ->find($id);
            if ($incidencia != NULL && $incidencia->getPathdocumento() != NULL){
                $ruta= $incidencia->getRuta() . $incidencia->getPathdocumento();
                if (file_exists($ruta)){
                    $headers = array('Content-Type' => "image/png",
                        'Content-Disposition' => 'inline; '
                        . 'filename="'.$ruta.'"');

                    $file =  readfile($ruta);
                    return new Response($file, 200, $headers); 
                }
            }
        }
        $response = new Response(json_encode(array()));
        return $response;
    }
    
    public function ajaxAction()
    {
        $numincidencias = 0;
        if($this->get('security.authorization_checker')->isGranted('ROLE_SUPER_ADMIN') === true){
            $em = $this->getDoctrine()->getManager();
            $numincidencias = $em->getRepository('IncidenciaBundle:incidencia')
                    ->findIncidenciaspendientes();
            
        }
        return new Response(json_encode(array("numincidencias" => $numincidencias)));
    }
}
