<?php

namespace AdministracionBundle\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\HttpFoundation\Request;
use Doctrine\ORM\Tools\Pagination\Paginator;
use PagoBundle\Entity\business;
use PagoBundle\Form\businessType;

class UserController extends Controller
{
    public function indexAction(Request $request, $page)
    {
        if(($this->get('security.authorization_checker')->isGranted('ROLE_SUPER_ADMIN') === true)){
            if ($page == NULL){
                $page = 1;
            }
            $text = $request->query->get("text");
            $idbusiness = intval($request->query->get("idbusiness"));
            $em = $this->getDoctrine()->getManager();
            $usuarioQuery = $em->getRepository('UsuarioBundle:administrador')
                    ->findAllusersQuery($idbusiness, $text, 1);
            $pageSize = 20;
            $usuarios = $this->getPaginate($pageSize, $page, $usuarioQuery);
            $totalItems = count($usuarios);
            $pagescount = ceil($totalItems / $pageSize);
            
            $abusiness = $em->getRepository('PagoBundle:business')->findBusiness();
            
            return $this->render('AdministracionBundle:Administracion:usuarioslist.html.twig' ,
                                array(  
                                    "usuarios" => $usuarios,
                                    "totalItems" => $totalItems,
                                    "pagesCount" => $pagescount,
                                    "currentpage" => $page,
                                    "text" => $text,
                                    "idbusiness" => $idbusiness,
                                    "abusiness" => $abusiness
                                    )
                                );
        }
        return $this->redirectToRoute('login');
    }
    
    public function eventosAction($id)
    {
        if(($this->get('security.authorization_checker')->isGranted('ROLE_SUPER_ADMIN') === true)){
            $em = $this->getDoctrine()->getManager();
            $administrador = $em->getRepository("UsuarioBundle:administrador")
                    ->find($id);
            if ($administrador){
                $eventosstripe = $em->getRepository('PagoBundle:eventostripe')
                        ->findEventosadministrador($administrador->getId());
                return $this->render('AdministracionBundle:Administracion:eventos.html.twig' ,
                                array(  "eventosstripe" => $eventosstripe,
                                        "administrador" => $administrador
                                    )
                                );
            }
        }
        return $this->redirectToRoute('usuarios_index');
    }
    
    public function getPaginate($pageSize, $currentPage, $queryBuilder){
        if ($currentPage > 0){
            $queryBuilder->setFirstResult($pageSize * ($currentPage - 1))->setMaxResults($pageSize);
        }
        $paginator = new Paginator($queryBuilder, $fetchJoinCollection = true);
        return $paginator;
    }
    
    public function editAction(Request $request, $id)
    {
        if(($this->get('security.authorization_checker')->isGranted('ROLE_SUPER_ADMIN') === true)){
            $em = $this->getDoctrine()->getManager();
            $editar = true;
            $idbusiness = 0;
            if($id == NULL){
                $business = new business();
                $editar = false;
            }else{
                $business = $em->getRepository('PagoBundle:business')->find($id);
                if($business == NULL){
                    $business = new business();
                    $editar = false; 
                }else{
                    $idbusiness = $business->getId();
                }
            }
            $planes = $em->getRepository('AdministracionBundle:plan')->findBy(array('business'=>$business,'eliminado'=>0));
            $form = $this->createForm(businessType::class, $business, 
                            array("attr" => array("disabled" => FALSE,'idbusiness'=>$idbusiness)));
            if($request->getMethod() == 'POST'){
                 $form->handleRequest($request);
                    if ($form->isSubmitted() && $form->isValid()) {
                        $business->setEstilo($business->getStyle()->getNombre());
                        $em->persist($business);
                        $em->flush();
                        return $this->redirectToRoute('usuarios_index');

                    }
            }
            return $this->render('AdministracionBundle:Administracion:businessedit.html.twig',array('form'=>$form->createView(),
                                'business'=>$business,'planes'=>$planes,'idbusiness'=>$idbusiness));
        }
        return $this->redirectToRoute('login');
    }
    
    public function deleteAction($id){
        if(($this->get('security.authorization_checker')->isGranted('ROLE_SUPER_ADMIN') === true)){
            $em = $this->getDoctrine()->getManager();
            $administrador = $em->getRepository('UsuarioBundle:administrador')->find($id);
            if($administrador){
                $administrador->setActivo(0);
                $em->persist($administrador);
                $em->flush();
            }
        }
        return $this->redirectToRoute('usuarios_index');
    }
    
    public function testemailAction(Request $request, $id)
    {
        if(($this->get('security.authorization_checker')->isGranted('ROLE_SUPER_ADMIN') === true)){
            $em = $this->getDoctrine()->getManager();
            $administrador = $em->getRepository("UsuarioBundle:administrador")
                    ->find($id);
            if ($administrador && $id == 35){
                $host = $request->getHost();
                $protocol = $request->getScheme();
                $url = $protocol . "://" . $host;
        
                $kernel = $this->get('kernel');
                $isdebug = $kernel->isDebug();
                
                if ($administrador->getCodigoverificacion() == NULL){
                    $administrador->setCodigoverificacion("TEST");
                }
                
                $enl = $this->generateUrl("registro_verificacion", 
                                            array("md5" => $administrador->getCodigoverificacion()));
                $enlace = $url . $enl;
                $business = $administrador->getBusiness(); 
                $style = NULL;
                if ($business){
                    $style = $business->getStyle();
                    if ($isdebug == true){
                        $this->render("PublicBundle:mail:activarregistro.html.twig", 
                                array("enlace" => $enlace, 
                                    "business" => $business, 
                                    "style" => $style,
                                    "url" => $url));
                        
                        $this->render("PublicBundle:mail:recuperarpassmail.html.twig", 
                                array("enlace" => $enlace, 
                                    "business" => $business, 
                                    "style" => $style,
                                    "usuario" => $administrador,
                                    "url" => $url));
                        
                        return $this->render("PublicBundle:mail:nuevoregistro.html.twig", 
                                            array("business" => $business, 
                                                    "style" => $style,
                                                    "url" => $url,
                                                    "usuario" => $administrador));
                    }else{
                        $body = $this->renderView("PublicBundle:mail:activarregistro.html.twig", 
                                array("enlace" => $enlace, 
                                    "business" => $business, 
                                    "style" => $style,
                                    "url" => $url));
                        
                        $body = $this->renderView("PublicBundle:mail:recuperarpassmail.html.twig", 
                                array("enlace" => $enlace, 
                                    "business" => $business, 
                                    "style" => $style,
                                    "usuario" => $administrador,
                                    "url" => $url));
                        $body = $this->renderView("PublicBundle:mail:nuevoregistro.html.twig", 
                                            array("business" => $business, 
                                                    "style" => $style,
                                                    "url" => $url,
                                                    "usuario" => $administrador));
                        
                        $transport =  \Swift_SmtpTransport::newInstance($business->getSmtphost(), $business->getSmtpport(),$business->getSmtpsecurity())
                                    ->setUsername($business->getEmail())
                                    ->setPassword($business->desencryptarPassword());

                        $titulopersonal = $business->getMensajeregistro();
                        $mailer = \Swift_Mailer::newInstance($transport);
                        $message = \Swift_Message::newInstance($titulopersonal)
                                    ->setFrom(array($business->getEmail() => "no-reply " . $business->getNombre()))
                                    ->setTo($administrador->getEmail())
                                    ->setBody($body, 'text/html');
                        $mailer->send($message);
                    }
                }
            }
        }
        return $this->redirectToRoute('usuarios_index');
    }
}
