<?php

namespace UsuarioBundle\Controller;

use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\HttpFoundation\Request;
use UsuarioBundle\Form\usuarioperfilType;
use UsuarioBundle\Form\usuariodatosfiscalesType;
use CoreBundle\Entity\Domainutils;
use CoreBundle\Entity\Cipher;

class UsuarioController extends Controller
{
    public function indexAction()
    {
        return $this->redirectToRoute("login");
    }
    
    public function mispagosAction(Request $request){
        if ($this->get('security.authorization_checker')->isGranted('ROLE_USER') === true){
            $usuario = $this->get('security.token_storage')->getToken()->getUser();
            $business = $usuario->getBusiness();
            $style = $business->getStyle();
            $em = $this->getDoctrine()->getManager();
            $eventosstripe = $em->getRepository('PagoBundle:eventostripe')
                                ->findEventosadministrador($usuario->getId());
            return $this->render('UsuarioBundle:Usuario:mispagos.html.twig',
                    array('usuario'=>$usuario,
                        "business" => $business,
                        "style" => $style,
                        "eventosstripe" => $eventosstripe
                    ));   
        }
        return $this->redirectToRoute('public_panel-index-user');
    }
    
    public function datosfacturacionAction(Request $request){
        if ($this->get('security.authorization_checker')->isGranted('ROLE_USER') === true){
            $usuario = $this->get('security.token_storage')->getToken()->getUser();
            $business = $usuario->getBusiness();
            $style = $business->getStyle();
            $form = $this->createForm(usuariodatosfiscalesType::class,
                                        $usuario,
                                        array("attr" => array("password"=>false,
                                                                "disabled" => false)));
            
            if($request->getMethod() == 'POST'){
                $form->handleRequest($request);
                if ($form->isSubmitted() && $form->isValid()) {
                    $em = $this->getDoctrine()->getManager();
                    $em->persist($usuario);
                    $em->flush();
                    return $this->redirectToRoute('public_panel-index-user');
                }
            }
            return $this->render('UsuarioBundle:Usuario:usuariodatosfiscales.html.twig',
                    array('form'=>$form->createView(), 
                        'usuario'=>$usuario,
                        "business" => $business,
                        "style" => $style
                    ));   
        }
        return $this->redirectToRoute('public_panel-index-user');
    }
    
    public function miperfilAction(Request $request){
        $em = $this->getDoctrine()->getManager(); 
        $usuario = $this->get('security.token_storage')->getToken()->getUser();
        $lastpassdecryp = NULL;
        if ($this->get('security.authorization_checker')->isGranted('ROLE_USER') === true){
            $business = $usuario->getBusiness();
            $lastpassdecryp = Cipher::decrypt($usuario->getPasscifrada());
        }else if ($this->get('security.authorization_checker')->isGranted('ROLE_SUPER_ADMIN') === true){
            $host = $request->getHost();
            $business = $em->getRepository("PagoBundle:business")->findNegocio($host); 
        }
        if ($business != NULL){
            $style = $business->getStyle();
            $lastpass = $usuario->getPassword();
            $form = $this->createForm(
                    usuarioperfilType::class,
                    $usuario,
                    array("attr" => array("password"=>false,
                                            "disabled" => false)));

            if($request->getMethod() == 'POST'){
                $form->handleRequest($request);
                if ($form->isSubmitted() && $form->isValid()) {
                    $em = $this->getDoctrine()->getManager();
                    $pass = $form["password"]->getData();  
                    if($pass != null){
                        $usuario->setSalt(md5(time()));
                        $encoder = $this->get('security.encoder_factory')->getEncoder($usuario);
                        $passwordCodificado = $encoder->encodePassword($pass, $usuario->getSalt());
                        $usuario->setPassword($passwordCodificado);
                        if ($this->get('security.authorization_checker')->isGranted('ROLE_USER') === true){
                            $token64 = Cipher::crypt($pass);
                            $usuario->setPasscifrada($token64);
                        }
                    }else{
                        $usuario->setPassword($lastpass);
                    }
                    $em->persist($usuario);
                    $em->flush();
                    if ($this->get('security.authorization_checker')->isGranted('ROLE_USER') === true){
                        if ($lastpass !== $pass && $usuario->getAplicacionactiva()){
                            list($errorcode, $errormessage, $return) = Domainutils::actualizarpass($usuario, $lastpassdecryp);
                        }
                        list($errorcode, $errormessage, $return) = Domainutils::actualizarpassweb($usuario, $lastpassdecryp);
                        return $this->redirectToRoute('public_panel-index-user');
                    }
                    return $this->redirectToRoute('business_index');
                }
            }
            if ($this->get('security.authorization_checker')->isGranted('ROLE_USER') === true){
                return $this->render('UsuarioBundle:Usuario:miperfilusuario.html.twig',
                    array('form'=>$form->createView(), 
                        'usuario'=>$usuario,
                        "business" => $business,
                        "style" => $style
                    ));
            }else if ($this->get('security.authorization_checker')->isGranted('ROLE_SUPER_ADMIN') === true){
                return $this->render('AdministracionBundle:Administracion:miperfil.html.twig',
                    array('form'=>$form->createView(), 
                        'usuario'=>$usuario,
                        "business" => $business,
                        "style" => $style
                    ));
            }
            
            
        }
        return $this->redirectToRoute('public_panel-index-user');
    }
}  
    